==> tuia-commercial-center-api-1.0.24-hrd-20200109.095111-3-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/finance/FarmFinanceConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm.finance;

import java.io.Serializable;
import java.util.Date;

public class FarmFinanceConfigDto implements Serializable {

    private static final long serialVersionUID = -379660533572431902L;

    private Long id;

    private Long appId;
    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Long budget;

    // 新增预算，单位分
    private Long addBudget;



    /*总预算*/
    private Long totalBudget;

    private Double constantC;

    private Double constantA;

    private Double constantPercent;

    private Double constantP;

    private Integer dayFixedRedPacketNum;

    private Integer dayMinRedPacketTimes;

    private Integer dayMaxRedPacketTimes;

    private Integer maxTaskRate;

    private Integer minTaskRate;

    private Integer dayMaxTaskNum;

    private Integer dayMinTaskNum;

    // 提现门槛单位分
    private Integer withdrawThreshold;

    // 预警门槛百分比
    private Double alarmThreshold;

    // 临界门槛百分比
    private Double limitThreshold;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public Integer getDayMinRedPacketTimes() {
        return dayMinRedPacketTimes;
    }

    public void setDayMinRedPacketTimes(Integer dayMinRedPacketTimes) {
        this.dayMinRedPacketTimes = dayMinRedPacketTimes;
    }

    public Integer getDayMaxRedPacketTimes() {
        return dayMaxRedPacketTimes;
    }

    public void setDayMaxRedPacketTimes(Integer dayMaxRedPacketTimes) {
        this.dayMaxRedPacketTimes = dayMaxRedPacketTimes;
    }

    public Integer getMaxTaskRate() {
        return maxTaskRate;
    }

    public void setMaxTaskRate(Integer maxTaskRate) {
        this.maxTaskRate = maxTaskRate;
    }

    public Integer getMinTaskRate() {
        return minTaskRate;
    }

    public void setMinTaskRate(Integer minTaskRate) {
        this.minTaskRate = minTaskRate;
    }

    public Integer getDayMaxTaskNum() {
        return dayMaxTaskNum;
    }

    public void setDayMaxTaskNum(Integer dayMaxTaskNum) {
        this.dayMaxTaskNum = dayMaxTaskNum;
    }

    public Integer getDayMinTaskNum() {
        return dayMinTaskNum;
    }

    public void setDayMinTaskNum(Integer dayMinTaskNum) {
        this.dayMinTaskNum = dayMinTaskNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Integer getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Integer withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public Double getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(Double alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public Double getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(Double limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getTotalBudget() {
        return totalBudget;
    }

    public void setTotalBudget(Long totalBudget) {
        this.totalBudget = totalBudget;
    }

    public Long getAddBudget() {
        return addBudget;
    }

    public void setAddBudget(Long addBudget) {
        this.addBudget = addBudget;
    }

    public Double getConstantC() {
        return constantC;
    }

    public void setConstantC(Double constantC) {
        this.constantC = constantC;
    }

    public Double getConstantA() {
        return constantA;
    }

    public void setConstantA(Double constantA) {
        this.constantA = constantA;
    }

    public Double getConstantPercent() {
        return constantPercent;
    }

    public void setConstantPercent(Double constantPercent) {
        this.constantPercent = constantPercent;
    }

    public Double getConstantP() {
        return constantP;
    }

    public void setConstantP(Double constantP) {
        this.constantP = constantP;
    }

    public Integer getDayFixedRedPacketNum() {
        return dayFixedRedPacketNum;
    }

    public void setDayFixedRedPacketNum(Integer dayFixedRedPacketNum) {
        this.dayFixedRedPacketNum = dayFixedRedPacketNum;
    }
}

==> tuia-commercial-center-api-1.0.28-hrd-20200213.041544-15-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/finance/FarmFinanceConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm.finance;

import java.io.Serializable;
import java.util.Date;

public class FarmFinanceConfigDto implements Serializable {

    private static final long serialVersionUID = -379660533572431902L;

    private Long id;

    private Long appId;
    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Long budget;

    // 新增预算，单位分
    private Long addBudget;



    /*总预算*/
    private Long totalBudget;

    private Double constantC;

    private Double constantA;

    private Double constantPercent;

    private Double constantP;

    private Integer dayFixedRedPacketNum;

    private Integer dayMinRedPacketTimes;

    private Integer dayMaxRedPacketTimes;


    private Integer dayMaxTaskNum;

    private Integer dayMinTaskNum;

    // 提现门槛单位分
    private Integer withdrawThreshold;

    // 预警门槛百分比
    private Double alarmThreshold;

    // 临界门槛百分比
    private Double limitThreshold;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    /**
     * 红包掉落概率
     */
    private Double redPacketRate;

    /**
     * 任务最小随机概率
     */
    private Double minTaskRate;

    /**
     * 任务最大随机概率
     */
    private Double maxTaskRate;


    /**
     * 红包过期天数
     */
    private Integer redPacketExpireDays;

    private Integer configVersion;

    private String imageUrl;

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public Integer getConfigVersion() {
        return configVersion;
    }

    public void setConfigVersion(Integer configVersion) {
        this.configVersion = configVersion;
    }

    public Double getRedPacketRate() {
        return redPacketRate;
    }

    public void setRedPacketRate(Double redPacketRate) {
        this.redPacketRate = redPacketRate;
    }

    public Double getMinTaskRate() {
        return minTaskRate;
    }

    public void setMinTaskRate(Double minTaskRate) {
        this.minTaskRate = minTaskRate;
    }

    public Double getMaxTaskRate() {
        return maxTaskRate;
    }

    public void setMaxTaskRate(Double maxTaskRate) {
        this.maxTaskRate = maxTaskRate;
    }

    public Integer getRedPacketExpireDays() {
        return redPacketExpireDays;
    }

    public void setRedPacketExpireDays(Integer redPacketExpireDays) {
        this.redPacketExpireDays = redPacketExpireDays;
    }

    public Integer getDayMinRedPacketTimes() {
        return dayMinRedPacketTimes;
    }

    public void setDayMinRedPacketTimes(Integer dayMinRedPacketTimes) {
        this.dayMinRedPacketTimes = dayMinRedPacketTimes;
    }

    public Integer getDayMaxRedPacketTimes() {
        return dayMaxRedPacketTimes;
    }

    public void setDayMaxRedPacketTimes(Integer dayMaxRedPacketTimes) {
        this.dayMaxRedPacketTimes = dayMaxRedPacketTimes;
    }


    public Integer getDayMaxTaskNum() {
        return dayMaxTaskNum;
    }

    public void setDayMaxTaskNum(Integer dayMaxTaskNum) {
        this.dayMaxTaskNum = dayMaxTaskNum;
    }

    public Integer getDayMinTaskNum() {
        return dayMinTaskNum;
    }

    public void setDayMinTaskNum(Integer dayMinTaskNum) {
        this.dayMinTaskNum = dayMinTaskNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Integer getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Integer withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public Double getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(Double alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public Double getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(Double limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getTotalBudget() {
        return totalBudget;
    }

    public void setTotalBudget(Long totalBudget) {
        this.totalBudget = totalBudget;
    }

    public Long getAddBudget() {
        return addBudget;
    }

    public void setAddBudget(Long addBudget) {
        this.addBudget = addBudget;
    }

    public Double getConstantC() {
        return constantC;
    }

    public void setConstantC(Double constantC) {
        this.constantC = constantC;
    }

    public Double getConstantA() {
        return constantA;
    }

    public void setConstantA(Double constantA) {
        this.constantA = constantA;
    }

    public Double getConstantPercent() {
        return constantPercent;
    }

    public void setConstantPercent(Double constantPercent) {
        this.constantPercent = constantPercent;
    }

    public Double getConstantP() {
        return constantP;
    }

    public void setConstantP(Double constantP) {
        this.constantP = constantP;
    }

    public Integer getDayFixedRedPacketNum() {
        return dayFixedRedPacketNum;
    }

    public void setDayFixedRedPacketNum(Integer dayFixedRedPacketNum) {
        this.dayFixedRedPacketNum = dayFixedRedPacketNum;
    }
}
